@@ -10,7 +10,7 @@ class MaemoApplication : public QObject {
     public:
         // constructors
         MaemoApplication ();
-        MaemoApplication (QString,QString,QString, QString _rating=QString(""),QString _downloads="",QString _comments="",QString _version="",QString _pre="",QString _bpre="");
+        MaemoApplication (QString,QString,QString, QString _rating=QString(""),QString _downloads="",QString _comments="",QString _version="",QString _pre="",QString _bpre="",QString _pers="");
         MaemoApplication (QString);
 
         //setting parameters
@@ -23,6 +23,7 @@ class MaemoApplication : public QObject {
         void setComments (QString _comments);
         void setPreview (QString _pre);
         void setBigPreview (QString _bpre);
+        void setPersonId (QString _per);
 
         //getting parameters
         QString getComments ();
@@ -34,6 +35,7 @@ class MaemoApplication : public QObject {
         QString getDownloads ();
         QString getPreview ();
         QString getBigPreview ();
+        QString getPersonId ();
 
         //output as QString
         QString toString ();
@@ -48,6 +50,7 @@ class MaemoApplication : public QObject {
             QString title;
             QString preview;
             QString bigPreview;
+            QString personId;
 
  };
 
