@@ -432,6 +432,11 @@ void MaemoApplicationHandler::parseAppListResponse(QByteArray content,int httpCo
                     qDebug() << "rating: " + xmlReader.text().toString() << endl;
                     app->setRating(xmlReader.text().toString());
                 }
+                else if (xmlReader.name() == "personid") {
+                    xmlReader.readNext();
+                    qDebug() << "person: " + xmlReader.text().toString() << endl;
+                    app->setPersonId(xmlReader.text().toString());
+                }
                 else if (xmlReader.name() == "name") {
                     xmlReader.readNext();
                     qDebug() << "title: " + xmlReader.text().toString() << endl;
@@ -529,6 +534,10 @@ void MaemoApplicationHandler::parseSingleAppResponse(QByteArray content, int htt
                         xmlReader.readNext();
                         appDetails->setRevisor(xmlReader.text().toString());
                     }
+                    else if (xmlReader.name()=="report_bugs") {
+                        xmlReader.readNext();
+                        appDetails->setBugUrl(xmlReader.text().toString());
+                    }
                     else if (xmlReader.name()=="rating") {
                         xmlReader.readNext();
                         appDetails->setRating(xmlReader.text().toString());
@@ -586,7 +595,7 @@ void MaemoApplicationHandler::parseSingleAppResponse(QByteArray content, int htt
                             if (xmlReader.isEndElement()&&xmlReader.name()=="value") {
                                 if (!userComment->getAuthor().isEmpty() && !userComment->getContent().isEmpty()) {
                                     qDebug() << "comment added" << endl;
-                                    appDetails->addUserComment (userComment);
+                                    appDetails->addUserComment (userComment,MaemoApplicationDetails::DESC);
                                 }
                             }
                             xmlReader.readNext();
@@ -671,7 +680,7 @@ void MaemoApplicationHandler::parseCommentsOnly (QByteArray com, int preloadComm
                 if (xmlReader.isEndElement()&&xmlReader.name()=="value") {
                     if (!userComment->getAuthor().isEmpty() && !userComment->getContent().isEmpty()) {
                         qDebug() << "comment added" << endl;
-                        comments->append (userComment);
+                        comments->prepend (userComment);
 
                         ++commentCount;
 
